pubtools-pyxis's documentation
============================

Contents:

.. toctree::
   :maxdepth: 2

   README
   entrypoints_reference
   modules_reference
   

.. toctree::
   :maxdepth: 1

   CHANGELOG

